export { default as prism } from './prism';
export declare const defaultColors: {
    white: string;
    black: string;
    gray: string[];
    success: string;
    successLight: string;
    successDark: string;
    error: string;
    errorLight: string;
    errorDark: string;
    warning: string;
    warningLight: string;
    warningDark: string;
    cyan: string;
    cyanLighter: string;
    cyanLight: string;
    cyanDark: string;
    violet: string;
    violetLighter: string;
    violetLight: string;
    violetDark: string;
    purple: string;
    alert: string;
    magenta: string;
};
export declare const darkColors: {
    gray: string[];
    success: string;
    successLight: string;
    successDark: string;
    error: string;
    errorLight: string;
    errorDark: string;
    warning: string;
    warningLight: string;
    warningDark: string;
};
export declare const colors: {
    modes: {
        dark: {
            gray: string[];
            success: string;
            successLight: string;
            successDark: string;
            error: string;
            errorLight: string;
            errorDark: string;
            warning: string;
            warningLight: string;
            warningDark: string;
            text: string;
            background: string;
            secondary: string;
            selection: string;
            link: string;
        };
    };
    white: string;
    black: string;
    gray: string[];
    success: string;
    successLight: string;
    successDark: string;
    error: string;
    errorLight: string;
    errorDark: string;
    warning: string;
    warningLight: string;
    warningDark: string;
    cyan: string;
    cyanLighter: string;
    cyanLight: string;
    cyanDark: string;
    violet: string;
    violetLighter: string;
    violetLight: string;
    violetDark: string;
    purple: string;
    alert: string;
    magenta: string;
    text: string;
    background: string;
    secondary: string;
    selection: string;
    link: string;
    code: string;
};
export declare const space: string[];
export declare const breakpoints: string[];
export declare const fonts: {
    body: string;
    heading: string;
    monospace: string;
    sans: string;
};
export declare const fontWeights: {
    body: number;
    heading: number;
    bold: number;
    light: number;
    normal: number;
};
export declare const fontSizes: Array<string>;
export declare const lineHeights: {
    body: number;
    heading: number;
};
export declare const sizes: {
    default: number;
    mini: number;
    small: number;
    medium: number;
    large: number;
    huge: number;
};
export declare const radii: {
    default: string;
    small: string;
    large: string;
    pill: string;
};
export declare const shadows: {
    default: string;
    dropdown: string;
    small: string;
    medium: string;
    large: string;
};
export declare const styles: {
    root: {
        fontFamily: string;
        bg: string;
        color: string;
        WebkitFontSmoothing: string;
        MozOsxFontSmoothing: string;
        textRendering: string;
        fontSize: string;
        lineHeight: string;
        margin: number;
        padding: number;
        minHeight: string;
        position: string;
        overflowX: string;
        '::selection': {
            bg: string;
            color: string;
        };
    };
    p: {
        margin: string;
        fontSize: string;
        lineHeight: string;
    };
    small: {
        margin: number;
        lineHeight: string;
        fontSize: string;
    };
    span: {
        fontSize: string;
        color: string;
        fontWeight: string;
    };
    strong: {
        fontWeight: string;
    };
    img: {
        height: string;
        maxWidth: string;
    };
    a: {
        color: string;
        textDecoration: string;
        cursor: string;
        alignItems: string;
        fontSize: string;
        WebkitTouchCallout: string;
        WebkitTapHighlightColor: string;
        ':hover': {
            textDecoration: string;
        };
    };
    'h1,h2,h3,h4,h5,h6': {
        fontFamily: string;
        m: number;
        mb: string;
        color: string;
    };
    h1: {
        fontSize: string;
        letterSpacing: string;
        lineHeight: string;
        fontWeight: string;
    };
    h2: {
        fontSize: string;
        letterSpacing: string;
        fontWeight: string;
    };
    h3: {
        fontSize: string;
        letterSpacing: string;
        fontWeight: string;
    };
    h4: {
        fontSize: string;
        letterSpacing: string;
        fontWeight: string;
    };
    h5: {
        fontSize: string;
        letterSpacing: string;
        fontWeight: string;
    };
    h6: {
        fontSize: string;
        letterSpacing: string;
        fontWeight: string;
    };
    ul: {
        margin: string;
        color: string;
        padding: number;
        listStyleType: string;
    };
    ol: {
        listStyleType: string;
    };
    li: {
        marginBottom: string;
        fontSize: string;
        lineHeight: string;
    };
    'ul li::before': {
        content: string;
        display: string;
        color: string;
        position: string;
        marginLeft: string;
    };
    blockquote: {
        display: string;
        width: string;
        px: number;
        ml: number;
        my: number;
        lineHeight: string;
        border: string;
        borderColor: string;
        bg: string;
        color: string;
        borderRadius: string;
    };
    inlineCode: {
        color: string;
        fontFamily: string;
        fontSize: string;
        whiteSpace: string;
        '::before,::after': {
            content: string;
        };
    };
    pre: {
        border: string;
        borderColor: string;
        borderRadius: string;
        py: number;
        px: number;
        my: number;
        whiteSpace: string;
        overflow: string;
        WebkitOverflowScrolling: string;
        code: {
            color: string;
            fontFamily: string;
            fontSize: string;
            lineHeight: number;
            whiteSpace: string;
            '::before,::after': {
                content: string;
                display: string;
            };
            ".token.comment": {
                color: string;
            };
            ".token.prolog": {
                color: string;
            };
            ".token.doctype": {
                color: string;
            };
            ".token.cdata": {
                color: string;
            };
            ".token.namespace": {
                opacity: number;
            };
            ".token.string": {
                color: string;
            };
            ".token.attr-value": {
                color: string;
            };
            ".token.punctuation": {
                color: string;
            };
            ".token.operator": {
                color: string;
            };
            ".token.url": {
                color: string;
            };
            ".token.symbol": {
                color: string;
            };
            ".token.boolean": {
                color: string;
            };
            ".token.variable": {
                color: string;
            };
            ".token.constant": {
                color: string;
            };
            ".token.atrule": {
                fontWeight: string;
            };
            ".language-autohotkey .token.selector": {
                fontWeight: string;
            };
            ".language-json .token.boolean": {
                color: string;
            };
            '.token.atrule, .language-autohotkey .token.selector, .language-json .token.boolean, code[class*="language-css"]': {
                fontWeight: string;
            };
            ".token.keyword": {
                color: string;
                fontWeight: string;
            };
            ".token.function": {
                color: string;
            };
            ".token.tag": {
                color: string;
            };
            ".token.class-name": {
                color: string;
            };
            ".token.number": {
                color: string;
            };
            ".token.tag .token.punctuation": {
                color: string;
            };
            ".language-autohotkey .token.tag": {
                color: string;
            };
            ".token.selector": {
                color: string;
            };
            ".language-autohotkey .token.keyword": {
                color: string;
            };
            ".token.important": {
                fontWeight: string;
            };
            ".token.bold": {
                fontWeight: string;
            };
            ".token.italic": {
                fontStyle: string;
            };
            ".token.deleted": {
                color: string;
                fontWeight: string;
            };
            ".token.inserted": {
                color: string;
                fontWeight: string;
            };
            ".language-json .token.property": {
                color: string;
                fontWeight: string;
            };
            ".language-markdown .token.title": {
                color: string;
                fontWeight: string;
            };
            ".language-markdown .token.code": {
                color: string;
                fontWeight: string;
            };
            ".language-markdown .token.list": {
                color: string;
            };
            ".language-markdown .token.hr": {
                color: string;
            };
            ".language-markdown .token.url": {
                color: string;
                fontWeight: string;
            };
            ".token.property": {
                color: string;
            };
            ".token.entity": {
                color: string;
            };
            ".token.attr-name": {
                color: string;
            };
            ".token.regex": {
                color: string;
            };
            ".token.directive.tag .tag": {
                background: string;
                color: string;
            };
        };
    };
    hr: {
        borderColor: string;
    };
    details: {
        bg: string;
    };
    table: {
        borderCollapse: string;
        borderSpacing: number;
        width: string;
        'thead th td': {
            height: string;
        };
        'tbody tr td': {
            height: string;
        };
        'tr td': {
            color: string;
            fontSize: number;
            height: string;
            borderBottom: string;
            borderBottomColor: string;
        };
        td: {
            padding: string;
            textAlign: string;
            ':first-of-type': {
                borderLeft: string;
            };
        };
        th: {
            borderTop: string;
            borderTopColor: string;
            borderBottom: string;
            borderBottomColor: string;
            bg: string;
            color: string;
            fontSize: number;
            fontWeight: string;
            letterSpacing: number;
            textAlign: string;
            height: string;
            padding: string;
            ':first-of-type': {
                borderLeft: string;
                borderLeftColor: string;
                borderRadius: string;
            };
            ':last-of-type': {
                borderRight: string;
                borderRightColor: string;
                borderRadius: string;
            };
        };
    };
};
export declare const avatars: {
    default: {
        display: string;
        position: string;
        overflow: string;
        width: string;
        height: string;
        border: string;
        borderColor: string;
        verticalAlign: string;
        bg: string;
        borderRadius: string;
        '& + &': {
            ml: number;
        };
    };
    small: {
        variant: string;
        width: string;
        height: string;
    };
    big: {
        variant: string;
        width: string;
        height: string;
    };
    huge: {
        variant: string;
        width: string;
        height: string;
    };
};
export declare const badges: {
    primary: {
        py: number;
        px: number;
        bg: string;
        color: string;
        display: string;
        fontSize: number;
        fontVariant: string;
        fontWeight: string;
        lineHeight: number;
        verticalAlign: string;
        borderRadius: string;
        textAlign: string;
    };
    success: {
        variant: string;
        bg: string;
    };
    warning: {
        variant: string;
        bg: string;
    };
    danger: {
        variant: string;
        bg: string;
    };
    error: {
        variant: string;
        bg: string;
    };
    secondary: {
        variant: string;
        bg: string;
    };
    mini: {
        variant: string;
        py: string;
        px: number;
        fontSize: string;
    };
    big: {
        variant: string;
        fontSize: number;
        lineHeight: number;
    };
    dot: {
        display: string;
        width: string;
        height: string;
        bg: string;
        borderRadius: string;
        padding: number;
        overflow: string;
        lineHeight: number;
        color: string;
    };
};
export declare const buttons: {
    primary: {
        bg: string;
        border: string;
        borderColor: string;
        borderRadius: string;
        color: string;
        cursor: string;
        display: string;
        fontSize: string;
        fontWeight: string;
        height: string;
        justifyContent: string;
        lineHeight: string;
        minWidth: string;
        outline: string;
        overflow: string;
        padding: string;
        position: string;
        textAlign: string;
        textTransform: string;
        transition: string;
        transitionProperty: string;
        userSelect: string;
        whiteSpace: string;
        width: string;
        ':hover,:focus': {
            color: string;
            bg: string;
            borderColor: string;
        };
    };
    mini: {
        variant: string;
        height: string;
        lineHeight: string;
        padding: string;
        width: string;
        minWidth: string;
        fontSize: string;
    };
    small: {
        variant: string;
        height: string;
        lineHeight: string;
        padding: string;
        width: string;
        minWidth: string;
        fontSize: string;
    };
    large: {
        variant: string;
        height: string;
        lineHeight: string;
        padding: string;
        width: string;
        minWidth: string;
        fontSize: string;
    };
    huge: {};
    big: {};
    success: {
        variant: string;
        borderColor: string;
        bg: string;
        color: string;
        ':hover,:focus': {
            color: string;
            bg: string;
            borderColor: string;
        };
    };
    warning: {
        variant: string;
        borderColor: string;
        bg: string;
        color: string;
        ':hover,:focus': {
            color: string;
            bg: string;
            borderColor: string;
        };
    };
    error: {
        variant: string;
        borderColor: string;
        bg: string;
        color: string;
        ':hover,:focus': {
            color: string;
            bg: string;
            borderColor: string;
        };
    };
    danger: {};
    abort: {
        variant: string;
        bg: string;
        borderColor: string;
        color: string;
        ':hover,:focus': {
            bg: string;
            borderColor: string;
            color: string;
        };
    };
    shadow: {
        variant: string;
        transitionProperty: string;
        boxShadow: string;
        ':hover,:focus': {
            boxShadow: string;
            transform: string;
        };
    };
    disabled: {
        '&,&:hover,&:focus': {
            variant: string;
            bg: string;
            borderColor: string;
            color: string;
            cursor: string;
        };
    };
};
export declare const cards: {
    primary: {
        bg: string;
        color: string;
        borderRadius: string;
        boxShadow: string;
        overflow: string;
        p: number;
        transition: string;
        width: string;
        border: string;
        borderColor: string;
        ':hover,:focus': {
            boxShadow: string;
        };
    };
    shadow: {
        variant: string;
        transition: string;
        boxShadow: string;
        ':hover,:focus': {
            boxShadow: string;
        };
    };
    border: {
        bg: string;
        color: string;
        borderRadius: string;
        boxShadow: string;
        overflow: string;
        p: number;
        width: string;
        border: string;
        borderColor: string;
    };
};
export declare const forms: {
    input: {
        fontFamily: string;
        padding: string;
        verticalAlign: string;
        alignItems: string;
        borderRadius: string;
        bg: string;
        fontSize: string;
        height: string;
        lineHeight: string;
        width: string;
        outline: number;
        mt: number;
        border: string;
        borderColor: string;
        WebkitAppearance: string;
        transition: string;
        ':focus': {
            borderColor: string;
        };
        ':disabled': {
            bg: string;
            cursor: string;
        };
        ':-webkit-autofill': {
            boxShadow: string;
        };
        '::-webkit-input-placeholder': {
            color: string;
        };
        '::-moz-placeholder': {
            color: string;
        };
        ':-ms-input-placeholder': {
            color: string;
        };
        '&[type="search"]::-webkit-search-decoration': {
            display: string;
        };
    };
    disabled: {
        variant: string;
        bg: string;
        cursor: string;
    };
    textarea: {
        variant: string;
        height: string;
        minHeight: string;
        lineHeight: string;
    };
    select: {
        variant: string;
        'input:checked ~ &': {
            color: string;
        };
    };
    radio: {
        color: string;
        'input:checked ~ &': {
            color: string;
        };
    };
    checkbox: {
        color: string;
    };
    small: {
        variant: string;
        fontSize: string;
        height: string;
        lineHeight: string;
    };
    large: {
        variant: string;
        fontSize: string;
        height: string;
        lineHeight: string;
    };
    error: {
        variant: string;
        borderColor: string;
        color: string;
    };
    success: {
        variant: string;
        borderColor: string;
        color: string;
    };
    label: {
        color: string;
        textAlign: string;
        fontSize: number;
        display: string;
        flexDirection: string;
    };
    labelHoriz: {
        color: string;
        textAlign: string;
        fontSize: number;
        display: string;
    };
    slider: {
        bg: string;
        color: string;
    };
    hidden: {
        position: string;
        height: string;
        width: string;
        overflow: string;
        clip: string;
        whiteSpace: string;
    };
};
export declare const layout: {
    container: {
        maxWidth: string;
        width: string;
        mx: string;
        px: number;
    };
    mini: {
        variant: string;
        maxWidth: string;
    };
    small: {
        variant: string;
        maxWidth: string;
    };
    medium: {
        variant: string;
        maxWidth: string;
    };
    large: {
        variant: string;
        maxWidth: string;
    };
    huge: {
        variant: string;
        maxWidth: string;
    };
};
export declare const geist: {
    breakpoints: string[];
    colors: {
        modes: {
            dark: {
                gray: string[];
                success: string;
                successLight: string;
                successDark: string;
                error: string;
                errorLight: string;
                errorDark: string;
                warning: string;
                warningLight: string;
                warningDark: string;
                text: string;
                background: string;
                secondary: string;
                selection: string;
                link: string;
            };
        };
        white: string;
        black: string;
        gray: string[];
        success: string;
        successLight: string;
        successDark: string;
        error: string;
        errorLight: string;
        errorDark: string;
        warning: string;
        warningLight: string;
        warningDark: string;
        cyan: string;
        cyanLighter: string;
        cyanLight: string;
        cyanDark: string;
        violet: string;
        violetLighter: string;
        violetLight: string;
        violetDark: string;
        purple: string;
        alert: string;
        magenta: string;
        text: string;
        background: string;
        secondary: string;
        selection: string;
        link: string;
        code: string;
    };
    space: string[];
    fonts: {
        body: string;
        heading: string;
        monospace: string;
        sans: string;
    };
    fontSizes: string[];
    fontWeights: {
        body: number;
        heading: number;
        bold: number;
        light: number;
        normal: number;
    };
    lineHeights: {
        body: number;
        heading: number;
    };
    sizes: {
        default: number;
        mini: number;
        small: number;
        medium: number;
        large: number;
        huge: number;
    };
    shadows: {
        default: string;
        dropdown: string;
        small: string;
        medium: string;
        large: string;
    };
    radii: {
        default: string;
        small: string;
        large: string;
        pill: string;
    };
    styles: {
        root: {
            fontFamily: string;
            bg: string;
            color: string;
            WebkitFontSmoothing: string;
            MozOsxFontSmoothing: string;
            textRendering: string;
            fontSize: string;
            lineHeight: string;
            margin: number;
            padding: number;
            minHeight: string;
            position: string;
            overflowX: string;
            '::selection': {
                bg: string;
                color: string;
            };
        };
        p: {
            margin: string;
            fontSize: string;
            lineHeight: string;
        };
        small: {
            margin: number;
            lineHeight: string;
            fontSize: string;
        };
        span: {
            fontSize: string;
            color: string;
            fontWeight: string;
        };
        strong: {
            fontWeight: string;
        };
        img: {
            height: string;
            maxWidth: string;
        };
        a: {
            color: string;
            textDecoration: string;
            cursor: string;
            alignItems: string;
            fontSize: string;
            WebkitTouchCallout: string;
            WebkitTapHighlightColor: string;
            ':hover': {
                textDecoration: string;
            };
        };
        'h1,h2,h3,h4,h5,h6': {
            fontFamily: string;
            m: number;
            mb: string;
            color: string;
        };
        h1: {
            fontSize: string;
            letterSpacing: string;
            lineHeight: string;
            fontWeight: string;
        };
        h2: {
            fontSize: string;
            letterSpacing: string;
            fontWeight: string;
        };
        h3: {
            fontSize: string;
            letterSpacing: string;
            fontWeight: string;
        };
        h4: {
            fontSize: string;
            letterSpacing: string;
            fontWeight: string;
        };
        h5: {
            fontSize: string;
            letterSpacing: string;
            fontWeight: string;
        };
        h6: {
            fontSize: string;
            letterSpacing: string;
            fontWeight: string;
        };
        ul: {
            margin: string;
            color: string;
            padding: number;
            listStyleType: string;
        };
        ol: {
            listStyleType: string;
        };
        li: {
            marginBottom: string;
            fontSize: string;
            lineHeight: string;
        };
        'ul li::before': {
            content: string;
            display: string;
            color: string;
            position: string;
            marginLeft: string;
        };
        blockquote: {
            display: string;
            width: string;
            px: number;
            ml: number;
            my: number;
            lineHeight: string;
            border: string;
            borderColor: string;
            bg: string;
            color: string;
            borderRadius: string;
        };
        inlineCode: {
            color: string;
            fontFamily: string;
            fontSize: string;
            whiteSpace: string;
            '::before,::after': {
                content: string;
            };
        };
        pre: {
            border: string;
            borderColor: string;
            borderRadius: string;
            py: number;
            px: number;
            my: number;
            whiteSpace: string;
            overflow: string;
            WebkitOverflowScrolling: string;
            code: {
                color: string;
                fontFamily: string;
                fontSize: string;
                lineHeight: number;
                whiteSpace: string;
                '::before,::after': {
                    content: string;
                    display: string;
                };
                ".token.comment": {
                    color: string;
                };
                ".token.prolog": {
                    color: string;
                };
                ".token.doctype": {
                    color: string;
                };
                ".token.cdata": {
                    color: string;
                };
                ".token.namespace": {
                    opacity: number;
                };
                ".token.string": {
                    color: string;
                };
                ".token.attr-value": {
                    color: string;
                };
                ".token.punctuation": {
                    color: string;
                };
                ".token.operator": {
                    color: string;
                };
                ".token.url": {
                    color: string;
                };
                ".token.symbol": {
                    color: string;
                };
                ".token.boolean": {
                    color: string;
                };
                ".token.variable": {
                    color: string;
                };
                ".token.constant": {
                    color: string;
                };
                ".token.atrule": {
                    fontWeight: string;
                };
                ".language-autohotkey .token.selector": {
                    fontWeight: string;
                };
                ".language-json .token.boolean": {
                    color: string;
                };
                '.token.atrule, .language-autohotkey .token.selector, .language-json .token.boolean, code[class*="language-css"]': {
                    fontWeight: string;
                };
                ".token.keyword": {
                    color: string;
                    fontWeight: string;
                };
                ".token.function": {
                    color: string;
                };
                ".token.tag": {
                    color: string;
                };
                ".token.class-name": {
                    color: string;
                };
                ".token.number": {
                    color: string;
                };
                ".token.tag .token.punctuation": {
                    color: string;
                };
                ".language-autohotkey .token.tag": {
                    color: string;
                };
                ".token.selector": {
                    color: string;
                };
                ".language-autohotkey .token.keyword": {
                    color: string;
                };
                ".token.important": {
                    fontWeight: string;
                };
                ".token.bold": {
                    fontWeight: string;
                };
                ".token.italic": {
                    fontStyle: string;
                };
                ".token.deleted": {
                    color: string;
                    fontWeight: string;
                };
                ".token.inserted": {
                    color: string;
                    fontWeight: string;
                };
                ".language-json .token.property": {
                    color: string;
                    fontWeight: string;
                };
                ".language-markdown .token.title": {
                    color: string;
                    fontWeight: string;
                };
                ".language-markdown .token.code": {
                    color: string;
                    fontWeight: string;
                };
                ".language-markdown .token.list": {
                    color: string;
                };
                ".language-markdown .token.hr": {
                    color: string;
                };
                ".language-markdown .token.url": {
                    color: string;
                    fontWeight: string;
                };
                ".token.property": {
                    color: string;
                };
                ".token.entity": {
                    color: string;
                };
                ".token.attr-name": {
                    color: string;
                };
                ".token.regex": {
                    color: string;
                };
                ".token.directive.tag .tag": {
                    background: string;
                    color: string;
                };
            };
        };
        hr: {
            borderColor: string;
        };
        details: {
            bg: string;
        };
        table: {
            borderCollapse: string;
            borderSpacing: number;
            width: string;
            'thead th td': {
                height: string;
            };
            'tbody tr td': {
                height: string;
            };
            'tr td': {
                color: string;
                fontSize: number;
                height: string;
                borderBottom: string;
                borderBottomColor: string;
            };
            td: {
                padding: string;
                textAlign: string;
                ':first-of-type': {
                    borderLeft: string;
                };
            };
            th: {
                borderTop: string;
                borderTopColor: string;
                borderBottom: string;
                borderBottomColor: string;
                bg: string;
                color: string;
                fontSize: number;
                fontWeight: string;
                letterSpacing: number;
                textAlign: string;
                height: string;
                padding: string;
                ':first-of-type': {
                    borderLeft: string;
                    borderLeftColor: string;
                    borderRadius: string;
                };
                ':last-of-type': {
                    borderRight: string;
                    borderRightColor: string;
                    borderRadius: string;
                };
            };
        };
    };
    avatars: {
        default: {
            display: string;
            position: string;
            overflow: string;
            width: string;
            height: string;
            border: string;
            borderColor: string;
            verticalAlign: string;
            bg: string;
            borderRadius: string;
            '& + &': {
                ml: number;
            };
        };
        small: {
            variant: string;
            width: string;
            height: string;
        };
        big: {
            variant: string;
            width: string;
            height: string;
        };
        huge: {
            variant: string;
            width: string;
            height: string;
        };
    };
    badges: {
        primary: {
            py: number;
            px: number;
            bg: string;
            color: string;
            display: string;
            fontSize: number;
            fontVariant: string;
            fontWeight: string;
            lineHeight: number;
            verticalAlign: string;
            borderRadius: string;
            textAlign: string;
        };
        success: {
            variant: string;
            bg: string;
        };
        warning: {
            variant: string;
            bg: string;
        };
        danger: {
            variant: string;
            bg: string;
        };
        error: {
            variant: string;
            bg: string;
        };
        secondary: {
            variant: string;
            bg: string;
        };
        mini: {
            variant: string;
            py: string;
            px: number;
            fontSize: string;
        };
        big: {
            variant: string;
            fontSize: number;
            lineHeight: number;
        };
        dot: {
            display: string;
            width: string;
            height: string;
            bg: string;
            borderRadius: string;
            padding: number;
            overflow: string;
            lineHeight: number;
            color: string;
        };
    };
    buttons: {
        primary: {
            bg: string;
            border: string;
            borderColor: string;
            borderRadius: string;
            color: string;
            cursor: string;
            display: string;
            fontSize: string;
            fontWeight: string;
            height: string;
            justifyContent: string;
            lineHeight: string;
            minWidth: string;
            outline: string;
            overflow: string;
            padding: string;
            position: string;
            textAlign: string;
            textTransform: string;
            transition: string;
            transitionProperty: string;
            userSelect: string;
            whiteSpace: string;
            width: string;
            ':hover,:focus': {
                color: string;
                bg: string;
                borderColor: string;
            };
        };
        mini: {
            variant: string;
            height: string;
            lineHeight: string;
            padding: string;
            width: string;
            minWidth: string;
            fontSize: string;
        };
        small: {
            variant: string;
            height: string;
            lineHeight: string;
            padding: string;
            width: string;
            minWidth: string;
            fontSize: string;
        };
        large: {
            variant: string;
            height: string;
            lineHeight: string;
            padding: string;
            width: string;
            minWidth: string;
            fontSize: string;
        };
        huge: {};
        big: {};
        success: {
            variant: string;
            borderColor: string;
            bg: string;
            color: string;
            ':hover,:focus': {
                color: string;
                bg: string;
                borderColor: string;
            };
        };
        warning: {
            variant: string;
            borderColor: string;
            bg: string;
            color: string;
            ':hover,:focus': {
                color: string;
                bg: string;
                borderColor: string;
            };
        };
        error: {
            variant: string;
            borderColor: string;
            bg: string;
            color: string;
            ':hover,:focus': {
                color: string;
                bg: string;
                borderColor: string;
            };
        };
        danger: {};
        abort: {
            variant: string;
            bg: string;
            borderColor: string;
            color: string;
            ':hover,:focus': {
                bg: string;
                borderColor: string;
                color: string;
            };
        };
        shadow: {
            variant: string;
            transitionProperty: string;
            boxShadow: string;
            ':hover,:focus': {
                boxShadow: string;
                transform: string;
            };
        };
        disabled: {
            '&,&:hover,&:focus': {
                variant: string;
                bg: string;
                borderColor: string;
                color: string;
                cursor: string;
            };
        };
    };
    cards: {
        primary: {
            bg: string;
            color: string;
            borderRadius: string;
            boxShadow: string;
            overflow: string;
            p: number;
            transition: string;
            width: string;
            border: string;
            borderColor: string;
            ':hover,:focus': {
                boxShadow: string;
            };
        };
        shadow: {
            variant: string;
            transition: string;
            boxShadow: string;
            ':hover,:focus': {
                boxShadow: string;
            };
        };
        border: {
            bg: string;
            color: string;
            borderRadius: string;
            boxShadow: string;
            overflow: string;
            p: number;
            width: string;
            border: string;
            borderColor: string;
        };
    };
    forms: {
        input: {
            fontFamily: string;
            padding: string;
            verticalAlign: string;
            alignItems: string;
            borderRadius: string;
            bg: string;
            fontSize: string;
            height: string;
            lineHeight: string;
            width: string;
            outline: number;
            mt: number;
            border: string;
            borderColor: string;
            WebkitAppearance: string;
            transition: string;
            ':focus': {
                borderColor: string;
            };
            ':disabled': {
                bg: string;
                cursor: string;
            };
            ':-webkit-autofill': {
                boxShadow: string;
            };
            '::-webkit-input-placeholder': {
                color: string;
            };
            '::-moz-placeholder': {
                color: string;
            };
            ':-ms-input-placeholder': {
                color: string;
            };
            '&[type="search"]::-webkit-search-decoration': {
                display: string;
            };
        };
        disabled: {
            variant: string;
            bg: string;
            cursor: string;
        };
        textarea: {
            variant: string;
            height: string;
            minHeight: string;
            lineHeight: string;
        };
        select: {
            variant: string;
            'input:checked ~ &': {
                color: string;
            };
        };
        radio: {
            color: string;
            'input:checked ~ &': {
                color: string;
            };
        };
        checkbox: {
            color: string;
        };
        small: {
            variant: string;
            fontSize: string;
            height: string;
            lineHeight: string;
        };
        large: {
            variant: string;
            fontSize: string;
            height: string;
            lineHeight: string;
        };
        error: {
            variant: string;
            borderColor: string;
            color: string;
        };
        success: {
            variant: string;
            borderColor: string;
            color: string;
        };
        label: {
            color: string;
            textAlign: string;
            fontSize: number;
            display: string;
            flexDirection: string;
        };
        labelHoriz: {
            color: string;
            textAlign: string;
            fontSize: number;
            display: string;
        };
        slider: {
            bg: string;
            color: string;
        };
        hidden: {
            position: string;
            height: string;
            width: string;
            overflow: string;
            clip: string;
            whiteSpace: string;
        };
    };
    layout: {
        container: {
            maxWidth: string;
            width: string;
            mx: string;
            px: number;
        };
        mini: {
            variant: string;
            maxWidth: string;
        };
        small: {
            variant: string;
            maxWidth: string;
        };
        medium: {
            variant: string;
            maxWidth: string;
        };
        large: {
            variant: string;
            maxWidth: string;
        };
        huge: {
            variant: string;
            maxWidth: string;
        };
    };
};
export default geist;
//# sourceMappingURL=index.d.ts.map